package com.ruoyi.tcZz.service;

import java.util.List;
import com.ruoyi.tcZz.domain.TcDbdw;
import com.ruoyi.tcZz.domain.TcWljg;

/**
 * 等保单位Service接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface ITcDbdwService 
{
    /**
     * 查询等保单位
     * 
     * @param id 等保单位主键
     * @return 等保单位
     */
    public TcDbdw selectTcDbdwById(Long id);

    /**
     * 查询等保单位列表
     * 
     * @param tcDbdw 等保单位
     * @return 等保单位集合
     */
    public List<TcDbdw> selectTcDbdwList(TcDbdw tcDbdw);

    /**
     * 新增等保单位
     * 
     * @param tcDbdw 等保单位
     * @return 结果
     */
    public int insertTcDbdw(TcDbdw tcDbdw);

    /**
     * 修改等保单位
     * 
     * @param tcDbdw 等保单位
     * @return 结果
     */
    public int updateTcDbdw(TcDbdw tcDbdw);

    /**
     * 批量删除等保单位
     * 
     * @param ids 需要删除的等保单位主键集合
     * @return 结果
     */
    public int deleteTcDbdwByIds(Long[] ids);

    /**
     * 删除等保单位信息
     * 
     * @param id 等保单位主键
     * @return 结果
     */
    public int deleteTcDbdwById(Long id);


    /**
     * 导入等保单位信息
     *
     * @return 结果
     */
    public String importUser(List<TcDbdw> tcDbdwList);
    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
